Internal Modules
================

:mod:`~PIL._binary` Module
--------------------------

.. automodule:: PIL._binary
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL._tkinter_finder` Module
----------------------------------

.. automodule:: PIL._tkinter_finder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL._util` Module
------------------------

.. automodule:: PIL._util
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~PIL._version` Module
---------------------------

.. module:: PIL._version

.. data:: __version__
    :annotation:
    :type: str

    This is the master version number for Pillow,
    all other uses reference this module.

:mod:`PIL.Image.core` Module
----------------------------

.. module:: PIL._imaging
.. module:: PIL.Image.core

An internal interface module previously known as :mod:`~PIL._imaging`,
implemented in :file:`_imaging.c`.
